Rdocumentation
powered by
Learn R Programming
helpr (version 0.2.0)
solr_similar: Similar pages. Find related pages and return info in a data.frame
Description
Similar pages. Find related pages and return info in a data.frame
Usage
solr_similar(topic)
Arguments
topic
title to be used to find similar results