list_to_double_list: Make a list into a nested list.
this is to be done to easily use sapply and keep the name of the item
Description
Make a list into a nested list. this is to be done to
easily use sapply and keep the name of the item
Usage
list_to_double_list(obj)